import { db } from "$lib/server/db";
import * as table from "$lib/server/db/schema"

export const GET = async () => {
  // Get all sensor data (like the original working version)
  const rawData = await db.select({ 
    altitude: table.sensorData.altitude, 
    humidity: table.sensorData.humidity, 
    pressure: table.sensorData.pressure, 
    temperature: table.sensorData.temperature, 
    date: table.sensorData.time, 
  }).from(table.sensorData);
  
  // Scale pressure values to be in a similar range as other sensors
  // Divide by 1000 to convert from Pa to kPa (more reasonable scale)
  const data = rawData.map(item => ({
    ...item,
    pressure: Math.round((item.pressure / 1000) * 10) / 10 // Convert to kPa with 1 decimal place
  }));
  
  console.log(`Returning ${data.length} data points`);

  return new Response(JSON.stringify(data), {
    headers: {
      "Content-Type": "application/json"
    }
  });
}
